@@ -1,7 +1,7 @@
 /*
  * IRC Helper Plugin for libpurple
  *
- * Copyright (C) 2005-2008, Richard Laager <rlaager@pidgin.im>
+ * Copyright (C) 2005-2009, Richard Laager <rlaager@pidgin.im>
  * Copyright (C) 2004-2005, Mathias Hasselmann <mathias@taschenorakel.de>
  * Copyright (C) 2005, Daniel Beardsmore <uilleann@users.sf.net>
  * Copyright (C) 2005, Björn Nilsson <BNI on irc.freenode.net>
@@ -55,13 +55,14 @@
 /* Copied from SECS_BEFORE_RESENDING_AUTORESPONSE in src/server.c */
 #define AUTO_RESPONSE_INTERVAL 600
 
+#define DOMAIN_SUFFIX_DALNET ".dal.net"
 #define DOMAIN_SUFFIX_FREENODE ".freenode.net"
 #define DOMAIN_SUFFIX_FUNCOM ".funcom.com"
 #define DOMAIN_SUFFIX_GAMESURGE ".gamesurge.net"
-#define DOMAIN_SUFFIX_THUNDERCITY ".thundercity.org"
-#define DOMAIN_SUFFIX_DALNET ".dal.net"
+#define DOMAIN_SUFFIX_INDIEZEN ".indiezen.org"
 #define DOMAIN_SUFFIX_JEUX ".jeux.fr"
 #define DOMAIN_SUFFIX_QUAKENET ".quakenet.org"
+#define DOMAIN_SUFFIX_THUNDERCITY ".thundercity.org"
 #define DOMAIN_SUFFIX_UNDERNET ".undernet.org"
 
 #define MESSAGE_CHANSERV_ACCESS_LIST_ADD "You have been added to the access list for "
@@ -86,7 +87,9 @@
 #define MESSAGE_NICKSERV_CLOAKED " set your hostname to"
 #define MESSAGE_NICKSERV_ID_FAILURE "Password Incorrect"
 #define MESSAGE_NICKSERV_IDENTIFIED "Password accepted - you are now recognized"
+#define MESSAGE_NICKSERV_IDENTIFIED_INDIEZEN "Password accepted -- you are now recognized."
 #define MESSAGE_SPOOFING_YOUR_IP "*** Spoofing your IP. congrats."
+#define MESSAGE_SET_HOSTNAME "idoru set your hostname to"
 #define MESSAGE_QUAKENET_Q_CRUFT \
 	"Remember: NO-ONE from QuakeNet will ever ask for your password.  " \
 	"NEVER send your password to ANYONE except Q@CServe.quakenet.org."
@@ -143,6 +146,7 @@ typedef enum {
 	IRC_NETWORK_TYPE_THUNDERCITY = 0x0400,
 	IRC_NETWORK_TYPE_DALNET    = 0x0800,
 	IRC_NETWORK_TYPE_FUNCOM    = 0x1000,
+	IRC_NETWORK_TYPE_INDIEZEN  = 0x2000,
 } IRCHelperStateFlags;
 
 struct proto_stuff
@@ -243,6 +247,8 @@ static IRCHelperStateFlags get_connection_type(PurpleConnection *connection)
 		type = IRC_NETWORK_TYPE_JEUX;
 	else if (g_str_has_suffix(username, DOMAIN_SUFFIX_UNDERNET))
 		type = IRC_NETWORK_TYPE_UNDERNET;
+	else if (g_str_has_suffix(username, DOMAIN_SUFFIX_INDIEZEN))
+		type = IRC_NETWORK_TYPE_INDIEZEN;
 
 	g_free(username);
 	return type;
@@ -633,6 +639,8 @@ static void signed_on_cb(PurpleConnection *connection)
 
 			if (state & IRC_NETWORK_TYPE_THUNDERCITY)
 				nickserv_msg_identify("AUTH", connection->proto_data, connection, nickpassword);
+			else if (state & IRC_NETWORK_TYPE_INDIEZEN)
+				nickserv_msg_identify("identify", connection->proto_data, connection, nickpassword);
 			else
 				nickserv_identify(connection->proto_data, connection, nickpassword);
 		}
@@ -921,6 +929,11 @@ static gboolean receiving_im_msg_cb(PurpleAccount *account, gchar **sender, gcha
 		return TRUE;
 	}
 
+	if (g_str_has_prefix(msg, MESSAGE_PURPLE_NOTICE_PREFIX MESSAGE_SET_HOSTNAME))
+	{
+		return TRUE;
+	}
+
 	/* SLIGHTLY COMPLICATED SUPPRESSION RULES */
 
 	/* Supress QuakeNet and UnderNet Weird Login Cruft */
@@ -1090,7 +1103,8 @@ static gboolean receiving_im_msg_cb(PurpleAccount *account, gchar **sender, gcha
 	{
 
 		/* Track that the identification is finished. */
-		if (g_str_equal(msg, MESSAGE_PURPLE_NOTICE_PREFIX MESSAGE_NICKSERV_IDENTIFIED))
+		if (g_str_equal(msg, MESSAGE_PURPLE_NOTICE_PREFIX MESSAGE_NICKSERV_IDENTIFIED) ||
+		    g_str_equal(msg, MESSAGE_PURPLE_NOTICE_PREFIX MESSAGE_NICKSERV_IDENTIFIED_INDIEZEN))
 			g_hash_table_insert(states, connection->proto_data,
 			                    GINT_TO_POINTER((state & ~IRC_KILLING_GHOST & ~IRC_WILL_ID)
 			                                    | IRC_DID_ID));
